@@ -64,14 +64,6 @@ module QuantLibc
     end
   end
 
-  TermStructure = YieldTermStructure
-  TermStructureHandle = YieldTermStructureHandle
-
-  CapFlatVolatilityStructure = CapVolatilityStructure
-  CapFlatVolatilityStructureHandle = CapVolatilityStructureHandle
-
-  CapFlatVolatilityVector = CapVolatilityVector
-
 end
 
 QuantLib = QuantLibc
